@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2013, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -40,15 +40,16 @@ class ZoneName {
 
     public static String toZid(String zid, Locale locale) {
         String mzone = zidToMzone.get(zid);
-        if (mzone == null && aliases.containsKey(zid)) {
-            zid = aliases.get(zid);
-            mzone = zidToMzone.get(zid);
+        if (mzone == null) {
+            String alias = aliases.get(zid);
+            if (alias != null) {
+                zid = alias;
+                mzone = zidToMzone.get(zid);
+            }
         }
         if (mzone != null) {
             Map<String, String> map = mzoneToZidL.get(mzone);
-            if (map != null && map.containsKey(locale.getCountry())) {
-                zid = map.get(locale.getCountry());
-            } else {
+            if (map == null || ((zid = map.get(locale.getCountry())) == null)) {
                 zid = mzoneToZid.get(mzone);
             }
         }
@@ -56,10 +57,7 @@ class ZoneName {
     }
 
     public static String toZid(String zid) {
-        if (aliases.containsKey(zid)) {
-            return aliases.get(zid);
-        }
-        return zid;
+        return aliases.getOrDefault(zid, zid);
     }
 
     private static final String[] zidMap = new String[] {
@@ -88,7 +86,7 @@ class ZoneName {
         "Africa/Gaborone", "Africa_Central", "Africa/Maputo",
         "Africa/Harare", "Africa_Central", "Africa/Maputo",
         "Africa/Johannesburg", "Africa_Southern", "Africa/Johannesburg",
-        "Africa/Juba", "Africa_Eastern", "Africa/Nairobi",
+        "Africa/Juba", "Africa_Central", "Africa/Maputo",
         "Africa/Kampala", "Africa_Eastern", "Africa/Nairobi",
         "Africa/Khartoum", "Africa_Central", "Africa/Maputo",
         "Africa/Kigali", "Africa_Central", "Africa/Maputo",
@@ -156,7 +154,8 @@ class ZoneName {
         "America/Cayenne", "French_Guiana", "America/Cayenne",
         "America/Cayman", "America_Eastern", "America/New_York",
         "America/Chicago", "America_Central", "America/Chicago",
-        "America/Chihuahua", "Mexico_Pacific", "America/Mazatlan",
+        "America/Chihuahua", "America_Central", "America/Chicago",
+        "America/Ciudad_Juarez", "America_Mountain", "America/Denver",
         "America/Coral_Harbour", "America_Eastern", "America/New_York",
         "America/Cordoba", "Argentina", "America/Buenos_Aires",
         "America/Costa_Rica", "America_Central", "America/Chicago",
@@ -164,7 +163,7 @@ class ZoneName {
         "America/Cuiaba", "Amazon", "America/Manaus",
         "America/Curacao", "Atlantic", "America/Halifax",
         "America/Danmarkshavn", "GMT", "Atlantic/Reykjavik",
-        "America/Dawson", "America_Pacific", "America/Los_Angeles",
+        "America/Dawson", "Yukon", "America/Whitehorse",
         "America/Dawson_Creek", "America_Mountain", "America/Denver",
         "America/Denver", "America_Mountain", "America/Denver",
         "America/Detroit", "America_Eastern", "America/New_York",
@@ -227,6 +226,7 @@ class ZoneName {
         "America/Moncton", "Atlantic", "America/Halifax",
         "America/Monterrey", "America_Central", "America/Chicago",
         "America/Montevideo", "Uruguay", "America/Montevideo",
+        "America/Montreal", "America_Eastern", "America/New_York",
         "America/Montserrat", "Atlantic", "America/Halifax",
         "America/Nassau", "America_Eastern", "America/New_York",
         "America/New_York", "America_Eastern", "America/New_York",
@@ -236,7 +236,8 @@ class ZoneName {
         "America/North_Dakota/Beulah", "America_Central", "America/Chicago",
         "America/North_Dakota/Center", "America_Central", "America/Chicago",
         "America/North_Dakota/New_Salem", "America_Central", "America/Chicago",
-        "America/Ojinaga", "America_Mountain", "America/Denver",
+        "America/Nuuk", "Greenland_Western", "America/Godthab",
+        "America/Ojinaga", "America_Central", "America/Chicago",
         "America/Panama", "America_Eastern", "America/New_York",
         "America/Pangnirtung", "America_Eastern", "America/New_York",
         "America/Paramaribo", "Suriname", "America/Paramaribo",
@@ -276,14 +277,14 @@ class ZoneName {
         "America/Tortola", "Atlantic", "America/Halifax",
         "America/Vancouver", "America_Pacific", "America/Los_Angeles",
         "America/Virgin", "Atlantic", "America/Halifax",
-        "America/Whitehorse", "America_Pacific", "America/Los_Angeles",
+        "America/Whitehorse", "Yukon", "America/Whitehorse",
         "America/Winnipeg", "America_Central", "America/Chicago",
         "America/Yakutat", "Alaska", "America/Juneau",
         "America/Yellowknife", "America_Mountain", "America/Denver",
-        "Antarctica/Casey", "Australia_Western", "Australia/Perth",
+        "Antarctica/Casey", "Casey", "Antarctica/Casey",
         "Antarctica/Davis", "Davis", "Antarctica/Davis",
         "Antarctica/DumontDUrville", "DumontDUrville", "Antarctica/DumontDUrville",
-        "Antarctica/Macquarie", "Macquarie", "Antarctica/Macquarie",
+        "Antarctica/Macquarie", "Australia_Eastern", "Australia/Sydney",
         "Antarctica/Mawson", "Mawson", "Antarctica/Mawson",
         "Antarctica/McMurdo", "New_Zealand", "Pacific/Auckland",
         "Antarctica/Rothera", "Rothera", "Antarctica/Rothera",
@@ -294,7 +295,6 @@ class ZoneName {
         "Arctic/Longyearbyen", "Europe_Central", "Europe/Paris",
         "Asia/Aden", "Arabian", "Asia/Riyadh",
         "Asia/Almaty", "Kazakhstan_Eastern", "Asia/Almaty",
-        "Asia/Amman", "Europe_Eastern", "Europe/Bucharest",
         "Asia/Anadyr", "Anadyr", "Asia/Anadyr",
         "Asia/Aqtau", "Kazakhstan_Western", "Asia/Aqtobe",
         "Asia/Aqtobe", "Kazakhstan_Western", "Asia/Aqtobe",
@@ -315,7 +315,6 @@ class ZoneName {
         "Asia/Chungking", "China", "Asia/Shanghai",
         "Asia/Colombo", "India", "Asia/Calcutta",
         "Asia/Dacca", "Bangladesh", "Asia/Dhaka",
-        "Asia/Damascus", "Europe_Eastern", "Europe/Bucharest",
         "Asia/Dhaka", "Bangladesh", "Asia/Dhaka",
         "Asia/Dili", "East_Timor", "Asia/Dili",
         "Asia/Dubai", "Gulf", "Asia/Dubai",
@@ -434,7 +433,7 @@ class ZoneName {
         "Canada/Newfoundland", "Newfoundland", "America/St_Johns",
         "Canada/Pacific", "America_Pacific", "America/Los_Angeles",
         "Canada/Saskatchewan", "America_Central", "America/Chicago",
-        "Canada/Yukon", "America_Pacific", "America/Los_Angeles",
+        "Canada/Yukon", "Yukon", "America/Whitehorse",
         "Chile/Continental", "Chile", "America/Santiago",
         "Chile/EasterIsland", "Easter", "Pacific/Easter",
         "Cuba", "Cuba", "America/Havana",
@@ -468,6 +467,7 @@ class ZoneName {
         "Europe/Jersey", "GMT", "Atlantic/Reykjavik",
         "Europe/Kaliningrad", "Europe_Eastern", "Europe/Bucharest",
         "Europe/Kiev", "Europe_Eastern", "Europe/Bucharest",
+        "Europe/Kyiv", "Europe_Eastern", "Europe/Bucharest",
         "Europe/Lisbon", "Europe_Western", "Atlantic/Canary",
         "Europe/Ljubljana", "Europe_Central", "Europe/Paris",
         "Europe/London", "GMT", "Atlantic/Reykjavik",
@@ -554,6 +554,7 @@ class ZoneName {
         "Pacific/Guam", "Chamorro", "Pacific/Saipan",
         "Pacific/Honolulu", "Hawaii_Aleutian", "Pacific/Honolulu",
         "Pacific/Johnston", "Hawaii_Aleutian", "Pacific/Honolulu",
+        "Pacific/Kanton", "Phoenix_Islands", "Pacific/Enderbury",
         "Pacific/Kiritimati", "Line_Islands", "Pacific/Kiritimati",
         "Pacific/Kosrae", "Kosrae", "Pacific/Kosrae",
         "Pacific/Kwajalein", "Marshall_Islands", "Pacific/Majuro",
@@ -596,7 +597,6 @@ class ZoneName {
         "US/Michigan", "America_Eastern", "America/New_York",
         "US/Mountain", "America_Mountain", "America/Denver",
         "US/Pacific", "America_Pacific", "America/Los_Angeles",
-        "US/Pacific-New", "America_Pacific", "America/Los_Angeles",
         "US/Samoa", "Samoa", "Pacific/Pago_Pago",
         "W-SU", "Moscow", "Europe/Moscow",
 
@@ -718,9 +718,7 @@ class ZoneName {
         "Europe_Eastern", "EG", "Africa/Cairo",
         "Europe_Eastern", "FI", "Europe/Helsinki",
         "Europe_Eastern", "GR", "Europe/Athens",
-        "Europe_Eastern", "JO", "Asia/Amman",
         "Europe_Eastern", "LB", "Asia/Beirut",
-        "Europe_Eastern", "SY", "Asia/Damascus",
         "Europe_Further_Eastern", "RU", "Europe/Kaliningrad",
         "Europe_Western", "FO", "Atlantic/Faeroe",
         "GMT", "BF", "Africa/Ouagadougou",
@@ -775,6 +773,7 @@ class ZoneName {
         "SystemV/YST9YDT", "America/Anchorage",
 
         // From tzdb
+        "Africa/Accra", "Africa/Abidjan",
         "Africa/Addis_Ababa", "Africa/Nairobi",
         "Africa/Asmara", "Africa/Nairobi",
         "Africa/Asmera", "Africa/Nairobi",
@@ -809,49 +808,63 @@ class ZoneName {
         "Africa/Ouagadougou", "Africa/Abidjan",
         "Africa/Porto-Novo", "Africa/Lagos",
         "Africa/Timbuktu", "Africa/Abidjan",
-        "America/Anguilla", "America/Port_of_Spain",
-        "America/Antigua", "America/Port_of_Spain",
+        "America/Anguilla", "America/Puerto_Rico",
+        "America/Antigua", "America/Puerto_Rico",
         "America/Argentina/ComodRivadavia", "America/Argentina/Catamarca",
-        "America/Aruba", "America/Curacao",
+        "America/Aruba", "America/Puerto_Rico",
+        "America/Atikokan", "America/Panama",
         "America/Atka", "America/Adak",
+        "America/Blanc-Sablon", "America/Puerto_Rico",
         "America/Buenos_Aires", "America/Argentina/Buenos_Aires",
         "America/Catamarca", "America/Argentina/Catamarca",
         "America/Cayman", "America/Panama",
-        "America/Coral_Harbour", "America/Atikokan",
+        "America/Coral_Harbour", "America/Panama",
         "America/Cordoba", "America/Argentina/Cordoba",
-        "America/Dominica", "America/Port_of_Spain",
+        "America/Creston", "America/Phoenix",
+        "America/Curacao", "America/Puerto_Rico",
+        "America/Dominica", "America/Puerto_Rico",
         "America/Ensenada", "America/Tijuana",
         "America/Fort_Wayne", "America/Indiana/Indianapolis",
         "America/Godthab", "America/Nuuk",
-        "America/Grenada", "America/Port_of_Spain",
-        "America/Guadeloupe", "America/Port_of_Spain",
+        "America/Grenada", "America/Puerto_Rico",
+        "America/Guadeloupe", "America/Puerto_Rico",
         "America/Indianapolis", "America/Indiana/Indianapolis",
         "America/Jujuy", "America/Argentina/Jujuy",
         "America/Knox_IN", "America/Indiana/Knox",
-        "America/Kralendijk", "America/Curacao",
+        "America/Kralendijk", "America/Puerto_Rico",
         "America/Louisville", "America/Kentucky/Louisville",
-        "America/Lower_Princes", "America/Curacao",
-        "America/Marigot", "America/Port_of_Spain",
+        "America/Lower_Princes", "America/Puerto_Rico",
+        "America/Marigot", "America/Puerto_Rico",
         "America/Mendoza", "America/Argentina/Mendoza",
         "America/Montreal", "America/Toronto",
-        "America/Montserrat", "America/Port_of_Spain",
+        "America/Montserrat", "America/Puerto_Rico",
+        "America/Nassau", "America/Toronto",
+        "America/Nipigon", "America/Toronto",
+        "America/Pangnirtung", "America/Iqaluit",
+        "America/Port_of_Spain", "America/Puerto_Rico",
         "America/Porto_Acre", "America/Rio_Branco",
+        "America/Rainy_River", "America/Winnipeg",
         "America/Rosario", "America/Argentina/Cordoba",
         "America/Santa_Isabel", "America/Tijuana",
         "America/Shiprock", "America/Denver",
-        "America/St_Barthelemy", "America/Port_of_Spain",
-        "America/St_Kitts", "America/Port_of_Spain",
-        "America/St_Lucia", "America/Port_of_Spain",
-        "America/St_Thomas", "America/Port_of_Spain",
-        "America/St_Vincent", "America/Port_of_Spain",
-        "America/Tortola", "America/Port_of_Spain",
-        "America/Virgin", "America/Port_of_Spain",
+        "America/St_Barthelemy", "America/Puerto_Rico",
+        "America/St_Kitts", "America/Puerto_Rico",
+        "America/St_Lucia", "America/Puerto_Rico",
+        "America/St_Thomas", "America/Puerto_Rico",
+        "America/St_Vincent", "America/Puerto_Rico",
+        "America/Thunder_Bay", "America/Toronto",
+        "America/Tortola", "America/Puerto_Rico",
+        "America/Virgin", "America/Puerto_Rico",
+        "America/Yellowknife", "America/Edmonton",
+        "Antarctica/DumontDUrville", "Pacific/Port_Moresby",
         "Antarctica/McMurdo", "Pacific/Auckland",
         "Antarctica/South_Pole", "Pacific/Auckland",
-        "Arctic/Longyearbyen", "Europe/Oslo",
+        "Antarctica/Syowa", "Asia/Riyadh",
+        "Arctic/Longyearbyen", "Europe/Berlin",
         "Asia/Aden", "Asia/Riyadh",
         "Asia/Ashkhabad", "Asia/Ashgabat",
         "Asia/Bahrain", "Asia/Qatar",
+        "Asia/Brunei", "Asia/Kuching",
         "Asia/Calcutta", "Asia/Kolkata",
         "Asia/Chongqing", "Asia/Shanghai",
         "Asia/Chungking", "Asia/Shanghai",
@@ -860,6 +873,7 @@ class ZoneName {
         "Asia/Istanbul", "Europe/Istanbul",
         "Asia/Kashgar", "Asia/Urumqi",
         "Asia/Katmandu", "Asia/Kathmandu",
+        "Asia/Kuala_Lumpur", "Asia/Singapore",
         "Asia/Kuwait", "Asia/Riyadh",
         "Asia/Macao", "Asia/Macau",
         "Asia/Muscat", "Asia/Dubai",
@@ -872,10 +886,12 @@ class ZoneName {
         "Asia/Ulan_Bator", "Asia/Ulaanbaatar",
         "Asia/Vientiane", "Asia/Bangkok",
         "Atlantic/Faeroe", "Atlantic/Faroe",
-        "Atlantic/Jan_Mayen", "Europe/Oslo",
+        "Atlantic/Jan_Mayen", "Europe/Berlin",
+        "Atlantic/Reykjavik", "Africa/Abidjan",
         "Atlantic/St_Helena", "Africa/Abidjan",
         "Australia/ACT", "Australia/Sydney",
         "Australia/Canberra", "Australia/Sydney",
+        "Australia/Currie", "Australia/Hobart",
         "Australia/LHI", "Australia/Lord_Howe",
         "Australia/NSW", "Australia/Sydney",
         "Australia/North", "Australia/Darwin",
@@ -909,23 +925,32 @@ class ZoneName {
         "Etc/UCT", "Etc/UTC",
         "Etc/Universal", "Etc/UTC",
         "Etc/Zulu", "Etc/UTC",
+        "Europe/Amsterdam", "Europe/Brussels",
         "Europe/Belfast", "Europe/London",
         "Europe/Bratislava", "Europe/Prague",
         "Europe/Busingen", "Europe/Zurich",
+        "Europe/Copenhagen", "Europe/Berlin",
         "Europe/Guernsey", "Europe/London",
         "Europe/Isle_of_Man", "Europe/London",
         "Europe/Jersey", "Europe/London",
+        "Europe/Kiev", "Europe/Kyiv",
         "Europe/Ljubljana", "Europe/Belgrade",
+        "Europe/Luxembourg", "Europe/Brussels",
         "Europe/Mariehamn", "Europe/Helsinki",
+        "Europe/Monaco", "Europe/Paris",
         "Europe/Nicosia", "Asia/Nicosia",
+        "Europe/Oslo", "Europe/Berlin",
         "Europe/Podgorica", "Europe/Belgrade",
         "Europe/San_Marino", "Europe/Rome",
         "Europe/Sarajevo", "Europe/Belgrade",
         "Europe/Skopje", "Europe/Belgrade",
+        "Europe/Stockholm", "Europe/Berlin",
         "Europe/Tiraspol", "Europe/Chisinau",
+        "Europe/Uzhgorod", "Europe/Kyiv",
         "Europe/Vaduz", "Europe/Zurich",
         "Europe/Vatican", "Europe/Rome",
         "Europe/Zagreb", "Europe/Belgrade",
+        "Europe/Zaporozhye", "Europe/Kyiv",
         "GB", "Europe/London",
         "GB-Eire", "Europe/London",
         "GMT", "Etc/GMT",
@@ -934,10 +959,15 @@ class ZoneName {
         "GMT0", "Etc/GMT",
         "Greenwich", "Etc/GMT",
         "Hongkong", "Asia/Hong_Kong",
-        "Iceland", "Atlantic/Reykjavik",
+        "Iceland", "Africa/Abidjan",
         "Indian/Antananarivo", "Africa/Nairobi",
+        "Indian/Christmas", "Asia/Bangkok",
+        "Indian/Cocos", "Asia/Yangon",
         "Indian/Comoro", "Africa/Nairobi",
+        "Indian/Kerguelen", "Indian/Maldives",
+        "Indian/Mahe", "Asia/Dubai",
         "Indian/Mayotte", "Africa/Nairobi",
+        "Indian/Reunion", "Asia/Dubai",
         "Iran", "Asia/Tehran",
         "Israel", "Asia/Jerusalem",
         "Jamaica", "America/Jamaica",
@@ -954,13 +984,20 @@ class ZoneName {
         "NZ-CHAT", "Pacific/Chatham",
         "Navajo", "America/Denver",
         "PRC", "Asia/Shanghai",
+        "Pacific/Chuuk", "Pacific/Port_Moresby",
+        "Pacific/Enderbury", "Pacific/Kanton",
+        "Pacific/Funafuti", "Pacific/Tarawa",
         "Pacific/Johnston", "Pacific/Honolulu",
+        "Pacific/Majuro", "Pacific/Tarawa",
         "Pacific/Midway", "Pacific/Pago_Pago",
-        "Pacific/Ponape", "Pacific/Pohnpei",
+        "Pacific/Pohnpei", "Pacific/Guadalcanal",
+        "Pacific/Ponape", "Pacific/Guadalcanal",
         "Pacific/Saipan", "Pacific/Guam",
         "Pacific/Samoa", "Pacific/Pago_Pago",
-        "Pacific/Truk", "Pacific/Chuuk",
-        "Pacific/Yap", "Pacific/Chuuk",
+        "Pacific/Truk", "Pacific/Port_Moresby",
+        "Pacific/Wake", "Pacific/Tarawa",
+        "Pacific/Wallis", "Pacific/Tarawa",
+        "Pacific/Yap", "Pacific/Port_Moresby",
         "Poland", "Europe/Warsaw",
         "Portugal", "Europe/Lisbon",
         "ROC", "Asia/Taipei",
@@ -979,7 +1016,6 @@ class ZoneName {
         "US/Michigan", "America/Detroit",
         "US/Mountain", "America/Denver",
         "US/Pacific", "America/Los_Angeles",
-        "US/Pacific-New", "America/Los_Angeles",
         "US/Samoa", "Pacific/Pago_Pago",
         "UTC", "Etc/UTC",
         "Universal", "Etc/UTC",
