@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -233,6 +229,7 @@ public class CurrencyNames_nl extends OpenListResourceBundle {
             { "MNT", "MNT" },
             { "MOP", "MOP" },
             { "MRO", "MRO" },
+            { "MRU", "MRU" },
             { "MTL", "MTL" },
             { "MTP", "MTP" },
             { "MUR", "MUR" },
@@ -317,7 +314,9 @@ public class CurrencyNames_nl extends OpenListResourceBundle {
             { "UYU", "UYU" },
             { "UZS", "UZS" },
             { "VEB", "VEB" },
+            { "VED", "VED" },
             { "VEF", "VEF" },
+            { "VES", "VES" },
             { "VNN", "VNN" },
             { "VUV", "VUV" },
             { "WST", "WST" },
@@ -408,7 +407,7 @@ public class CurrencyNames_nl extends OpenListResourceBundle {
             { "buk", "Birmese kyat" },
             { "bwp", "Botswaanse pula" },
             { "byb", "Wit-Russische nieuwe roebel (1994\u20131999)" },
-            { "byn", "Wit-Russische roebel" },
+            { "byn", "Belarussische roebel" },
             { "byr", "Wit-Russische roebel (2000\u20132016)" },
             { "bzd", "Belizaanse dollar" },
             { "cad", "Canadese dollar" },
@@ -419,9 +418,9 @@ public class CurrencyNames_nl extends OpenListResourceBundle {
             { "cle", "Chileense escudo" },
             { "clf", "Chileense unidades de fomento" },
             { "clp", "Chileense peso" },
-            { "cnh", "Chinese renminbi (offshore)" },
+            { "cnh", "Chinese yuan (offshore)" },
             { "cnx", "dollar van de Chinese Volksbank" },
-            { "cny", "Chinese Yuan" },
+            { "cny", "Chinese yuan" },
             { "cop", "Colombiaanse peso" },
             { "cou", "Unidad de Valor Real" },
             { "crc", "Costa Ricaanse colon" },
@@ -452,7 +451,7 @@ public class CurrencyNames_nl extends OpenListResourceBundle {
             { "fjd", "Fiji-dollar" },
             { "fkp", "Falklandeilands pond" },
             { "frf", "Franse franc" },
-            { "gbp", "Brits pond" },
+            { "gbp", "Britse pond" },
             { "gek", "Georgische kupon larit" },
             { "gel", "Georgische lari" },
             { "ghc", "Ghanese cedi (1979\u20132007)" },
@@ -578,7 +577,8 @@ public class CurrencyNames_nl extends OpenListResourceBundle {
             { "shp", "Sint-Heleens pond" },
             { "sit", "Sloveense tolar" },
             { "skk", "Slowaakse koruna" },
-            { "sll", "Sierraleoonse leone" },
+            { "sle", "Sierra Leoonse leone" },
+            { "sll", "Sierraleoonse leone (1964\u20142022)" },
             { "sos", "Somalische shilling" },
             { "srd", "Surinaamse dollar" },
             { "srg", "Surinaamse gulden" },
@@ -612,9 +612,12 @@ public class CurrencyNames_nl extends OpenListResourceBundle {
             { "uyi", "Uruguayaanse peso en ge\u00efndexeerde eenheden" },
             { "uyp", "Uruguayaanse peso (1975\u20131993)" },
             { "uyu", "Uruguayaanse peso" },
+            { "uyw", "Uruguayaanse nominale salarisindexeenheid" },
             { "uzs", "Oezbeekse sum" },
             { "veb", "Venezolaanse bolivar (1871\u20132008)" },
-            { "vef", "Venezolaanse bolivar" },
+            { "ved", "Bol\u00edvar Soberano" },
+            { "vef", "Venezolaanse bolivar (2008\u20132018)" },
+            { "ves", "Venezolaanse bolivar" },
             { "vnd", "Vietnamese dong" },
             { "vnn", "Vietnamese dong (1978\u20131985)" },
             { "vuv", "Vanuatuaanse vatu" },
